@@ -7,7 +7,7 @@ from typing import Iterable
 from tidylib import tidy_fragment
 from ..parser.template import parse_template, parse_use_statement
 from ..parser.selector import parse_selector
-from ..command_manager import register_command
+from ..command_manager import register_command, CommandManager
 from ..template_manager import TemplateCache
 from ..utils import remove_preserve_tail
 
@@ -27,7 +27,9 @@ def cmd_recursive(root):
 
 
 @register_command('foreach')
-def cmd_foreach(root, template):
+def cmd_foreach(root, *args, template=None):
+    if template is None and args:
+        return [CommandManager().run_command_line(args, child) for child in root]
     if isinstance(template, str):
         template = parse_use_statement(template)
     return [parse_template(template, child) for child in root]
@@ -81,6 +83,11 @@ def cmd_strip(root):
     return root.strip()
 
 
+@register_command('split')
+def cmd_split(root, char=None):
+    return root.split(char)
+
+
 @register_command('quote')
 def cmd_quote(root):
     return quote(root)
@@ -157,6 +164,19 @@ def cmd_select_one(root, selector):
     return results[0] if len(results) else None
 
 
+@register_command('select_or')
+def cmd_select_or(root, *selectors):
+    selectors = [parse_selector(selector) for selector in selectors]
+    selector = ' | '.join(selectors)
+    return root.xpath(selector)
+
+
+@register_command('select_one_or')
+def cmd_select_or(root, *selectors):
+    results = cmd_select_or(root, selectors)
+    return results[0] if len(results) else None
+
+
 @register_command('tidy')
 def cmd_tidy(root, **kwargs):
     default_options = {
